@@ -59,8 +59,15 @@
                             });
                         }catch(err){
                         }
-                        if(_this.next().parents("a").length > 0){
-                            _this.next().click(function(){return false;});
+                        var links_parents = _this.next().parents("a");
+                        if(links_parents.length > 0) {
+                            $.map(links_parents, function (link, i) {
+                                var link = $(link);
+                                var href = link.attr("href");
+                                link.attr("hrefinplaceedit", href);
+                                link.addClass("linkInplaceEdit");
+                                link.removeAttr("href");
+                            });
                         }
                         _this.next().find(".cancel").click(inplaceCancel);
                         _this.next().find(".apply").click(inplaceApply);
@@ -69,7 +76,18 @@
                 }});
             });
 
+            function revertlinkInplaceEdit(links_parents) {
+                $.map(links_parents, function (link, i) {
+                    var link = $(link);
+                    var href = link.attr("hrefinplaceedit");
+                    link.attr("href", href);
+                    link.removeClass("linkInplaceEdit");
+                    link.removeAttr("hrefinplaceedit");
+                });
+            }
+
             function inplaceCancel() {
+                revertlinkInplaceEdit($(this).parents("a.linkInplaceEdit"));
                 $(this).parent().prev().fadeIn();
                 $(this).parent().prev().removeClass("inplaceHide");
                 var cancelFinish = $(this).data("cancelFinish");
@@ -80,10 +98,23 @@
                 return false;
             }
 
+            function replaceAll(txt, replace, with_this) {
+                return txt.replace(new RegExp(replace, "g"), with_this);
+            }
+
             function inplaceApplySuccess(response){
                 if (typeof response == "string") {
-                    response = eval("( " + response + " )")
+                    if ($.browser.msie) {
+                        response = replaceAll(response, "'\\\\\"", "'");
+                        response = replaceAll(response, "\"'", "'"); 
+                    }
+                    try {
+                        response = JSON.parse(response);
+                    } catch(errno) {
+                        response = eval("( " + response + " )");
+                    }
                 }
+                revertlinkInplaceEdit($(this.form).parents("a.linkInplaceEdit"));
                 var _this = this.context;
                 var form = this.form;
                 var inplaceedit_conf = this.inplaceedit_conf;
@@ -112,7 +143,7 @@
                     inplace_span.removeClass("inplaceHide");
                     var applyFinish = $(_this).data("applyFinish");
                     if (applyFinish){
-                        applyFinish();
+                        applyFinish(_this);
                     }
                     _this.parent().remove();
                 }
@@ -142,7 +173,7 @@
                     url:  opts.saveURL,
                     type: "POST",
                     async: true,
-                    dataType: 'json',
+                    dataType: 'text',
                     success: bind(inplaceApplySuccess, {"context": $(this),
                                                         "form": form,
                                                         "inplaceedit_conf": inplaceedit_conf})});
@@ -168,7 +199,6 @@
 
                 form.ajaxSubmit({
                         url: opts.saveURL,
-                        debug: true,
                         data: data,
                         async: true,
                         type: "POST",
